#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ------------
#| Change Log |
# ------------
# Rel 0.1: Initial release. Inspired by plug-ins ofn-bend-path.py https://sourceforge.net/projects/gimp-path-tools/files/scripts/
# Rel 0.2: Add option: "Use Metallic Effects? based by Custom Font Metallic Effects v.0.3 for Gimp 2.10 by Skinnyhouse.
#          https://gimpchat.com/viewtopic.php?f=9&t=17818
# Rel 0.3: Add style: Trumpet. Due to an error in the number of parameters, it was abandoned run interaktive Custom Font Metallic Effects
# Rel 0.4: Add style: Fish, Heart.

from gimpfu import *
import os

def python_fu_text_to_ofn_bend_path(text, int, font, just, letter_spacing, line_spacing, font_size, background_color, background_opacity, style_top, style_bottom, add_back, fill, fillpattern, stroke, flatten, visible_v):

	# set background color
	gimp.set_background(background_color)

	# create image: width, height, type
	image = gimp.Image(font_size, font_size, RGB)

	# create layer with text and add it to the image: image, drawable, x, y, text, border, antialias, size, size_type, fontname
	text_layer = pdb.gimp_text_fontname(image, None, 0, 0, text, 0, 1, font_size, PIXELS, font)

	# justification:
	pdb.gimp_text_layer_set_justification (text_layer, just)
	pdb.gimp_text_layer_set_letter_spacing(text_layer, letter_spacing)
	pdb.gimp_text_layer_set_line_spacing(text_layer, line_spacing)
	
	# create path in text	
	new_vectors = pdb.gimp_vectors_new(image, text_layer)
	x=pdb.gimp_vectors_new_from_text_layer(image, text_layer)
	pdb.gimp_image_insert_vectors(image, x, None, -1)
	active_vectors = pdb.gimp_image_get_active_vectors(image)
	active_vectors.name = active_vectors.name.replace("Text", font)
	active_vectors.visible = True
	
	# resize image to layer content
	pdb.gimp_image_resize_to_layers(image)
	    
	# create layer: image, width, height, type, name, opacity, mode
	layer = gimp.Layer(image, "background", image.width, image.height, RGBA_IMAGE, background_opacity, 0)
	
	# append layer to the image
	image.add_layer(layer, 0)
	
	# create path envelope	
	pdb.gimp_selection_all(image)
	selection = pdb.gimp_selection_bounds(image)
	
	x1 = selection[1];
	y1 = selection[2];
	x2 = selection[3];
	y2 = selection[4];
	
	W1 = 2*(x1+(x2 - x1)/2)
	H1 = 2*(y1+(y2 - y1)/2)
	
	W2 =(x1+(x2 - x1)/2)
	H2 =(y1+(y2 - y1)/2)
	
	W3 = W1/3
	H3 = H1/3
	
	W4 = W2/2
	H4 = H2/2
	
	r=int
	new_vectors_e = pdb.gimp_vectors_new(image,"Envelope")
	pdb.gimp_image_insert_vectors(image, new_vectors_e, None, -1)
	
	pdb.gimp_item_set_visible(new_vectors_e, True)	
# style_top, style_bottom,
	if style_top==0:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 18, (x1,y1, x1,y1, x1,y1,  W4,y1-r, W2,-r, W2+W4,y1-r,  W1-x1,y1, W1-x1,y1 ,W1-x1,y1, ), 0)
	if style_top==1:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 18, (x1,y1-r, x1,y1-r, x1,y1-r,   W4,y1, W2,y1, W2+W4,y1,   x2,y1-r, x2,y1-r, x2,y1-r), 0)	
	if style_top==2:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y1, x1,y1, x1,y1,   W1-x1,y1, W1-x1,y1 ,W1-x1,y1, ), 0)	
	if style_top==3:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 18, (x1,y1, x1,y1, x1,y1,  W2,-r, W2,-r, W2,-r,  W1-x1,y1, W1-x1,y1 ,W1-x1,y1, ), 0)
	if style_top==4:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 18, (x1,y1-r, x1,y1-r, x1,y1-r,   W2,y1, W2,y1, W2,y1,   x2,y1-r, x2,y1-r, x2,y1-r), 0)	
	if style_top==5:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y1, x1,y1, x1,y1,  x2,y1-r, x2,y1-r, x2,y1-r), 0)
	if style_top==6:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y1-r, x1,y1-r, x1,y1-r,  W1-x1,y1, W1-x1,y1 ,W1-x1,y1 ), 0)
	if style_top==7:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 30, (x1,y1, x1,y1, x1,y1,    W4-r,y1-r,W4,y1-r,W4+r,y1-r,     W2,y1, W2,y1, W2,y1,    x2-W4-r,y1+r, x2-W4,y1+r, x2-W4+r,y1+r,     W1-x1,y1, W1-x1,y1 ,W1-x1,y1, ), 0)	
	if style_top==8:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 30, (x1,y1, x1,y1, x1,y1,    W4-r,y1+r,W4,y1+r,W4+r,y1+r,     W2,y1, W2,y1, W2,y1,    x2-W4-r,y1-r,x2-W4,y1-r,x2-W4+r,y1-r,     W1-x1,y1, W1-x1,y1 ,W1-x1,y1, ), 0)	
	if style_top==9:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 24, (x1,y1, x1,y1, x1,y1,  W3,y1-r, W3,-r, W3,y1-r,   2*W3,y1-r, 2*W3,-r, 2*W3,y1-r,   W1-x1,y1, W1-x1,y1 ,W1-x1,y1, ), 0)
	if style_top==10:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 24, (x1,y1, x1,y1, x1,y1,  W3,y1+r, W3,r, W3,y1+r,    2*W3,y1+r, 2*W3,r, 2*W3,y1+r,   W1-x1,y1, W1-x1,y1 ,W1-x1,y1, ), 0)
	if style_top==11:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y1, x1,y1, x1,y1,   x2,y1, W1-x1,y1-r ,W1-x1,y1-r, ), 0)
	if style_top==12:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y1-r, x1,y1-r, x1,y1,   W1-x1,y1, W1-x1,y1 ,W1-x1,y1, ), 0)
	if style_top==13:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 24, (x1,y1-r, x1,y1-r, x1,y1-r,  W4,y1+r/2, W4,y1+r/2, W4,y1+r/2,   2*W3-2*r,y1-r, 2*W3,y1-r, 2*W3+2*r,y1-r,  W1-x1,y1+r/2, W1-x1,y1+r/2 ,W1-x1,y1+r/2), 0)
	if style_top==14:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 24, (x1,y1+r/2, x1,y1+r/2 ,x1,y1+r/2,    W3-2*r,y1-r, W3,y1-r, W3+2*r,y1-r,   3*W4,y1+r/2, 3*W4,y1+r/2, 3*W4,y1+r/2,   x2,y1-r, x2,y1-r, x2,y1-r,), 0)
	if style_top==15:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 30, (x1,y1+r/3, x1,y1+r/3, x1,y1-r/2,    W4-r/2,y1-r, W4,y1-r, W4+r/2,y1-r,   W2,y1-r/3, W2,y1+r/4, W2,y1-r/3,    3*W4-r/2,y1-r, 3*W4,y1-r, 3*W4+r/2,y1-r,   W1-x1,y1-r/2, W1-x1,y1+r/3 ,W1-x1,y1+r/3), 0)		
	
	
	
	if style_bottom==0:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 18, (x1,y2+r, x1,y2+r, x1,y2+r,   W4,y2, W2,y2, W2+W4,y2,   x2,y2+r, x2,y2+r, x2,y2+r), 0)		
	if style_bottom==1:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 18, (x1,y2, x1,y2, x1,y2,   W4,y2+r, W2,y2+r, W2+W4,y2+r,   x2,y2, x2,y2, x2,y2), 0)	
	if style_bottom==2:   # line
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y2, x1,y2, x1,y2,   W1-x1,y2, W1-x1,y2 ,W1-x1,y2, ), 0)		
	if style_bottom==3: 
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 18, (x1,y2+r, x1,y2+r, x1,y2+r,   W2,y2, W2,y2, W2,y2,   x2,y2+r, x2,y2+r, x2,y2+r), 0)	
	if style_bottom==4:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 18, (x1,y2, x1,y2, x1,y2,   W2,y2+r, W2,y2+r, W2,y2+r,   x2,y2, x2,y2, x2,y2), 0)	
	if style_bottom==5:	
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y2+r, x1,y2+r, x1,y2+r,    x2,y2, x2,y2, x2,y2), 0)
	if style_bottom==6:	
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y2, x1,y2, x1,y2,  x2,y2+r, x2,y2+r, x2,y2+r), 0)		
	if style_bottom==7:	
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 30, (x1,y2, x1,y2, x1,y2,  W4-r,y2-r,W4,y2-r,W4+r,y2-r,  W2,y2, W2,y2, W2,y2,  x2-W4-r,y2+r, x2-W4,y2+r, x2-W4+r,y2+r,     W1-x1,y2, W1-x1,y2 ,W1-x1,y2, ), 0)
	if style_bottom==8:	
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 30, (x1,y2, x1,y2, x1,y2,    W4-r,y2+r,W4,y2+r,W4+r,y2+r,     W2,y2, W2,y2, W2,y2,    x2-W4-r,y2-r,x2-W4,y2-r,x2-W4+r,y2-r,     W1-x1,y2, W1-x1,y2 ,W1-x1,y2, ), 0)
	if style_bottom==9:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 24, (x1,y2+r, x1,y2+r, x1,y2+r,   W3,y2, W3,y2, W3,y2,    2*W3,y2, 2*W3,y2, 2*W3,y2,   W1-x1,y2+r, W1-x1,y2+r ,W1-x1,y2+r, ), 0)	
	if style_bottom==10: 
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 24, (x1,y2, x1,y2, x1,y2,    W3,y2+r, W3,y2+r,W3,y2+r,   2*W3,y2+r,2*W3,y2+r,2*W3,y2+r,   W1-x1,y2, W1-x1,y2 ,W1-x1,y2, ), 0)
	if style_bottom==11: 
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y2, x1,y2, x1,y2,   W1-x1,y2, W1-x1,y2+r ,W1-x1,y2+r, ), 0)	
	if style_bottom==12:  
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 12, (x1,y2+r, x1,y2+r, x1,y2,  W1-x1,y2, W1-x1,y2 ,W1-x1,y2,  ), 0)	
	if style_bottom==13:	
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 24, (x1,y2+r, x1,y2+r, x1,y2+r,   W4,y2-r/2, W4,y2-r/2, W4,y2-r/2,    2*W3-2*r,y2+r, 2*W3,y2+r, 2*W3+2*r,y2+r,   W1-x1,y2-r/2, W1-x1,y2-r/2 ,W1-x1,y2-r/2, ), 0)		
	if style_bottom==14:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 24, (x1,y2-r/2, x1,y2-r/2 ,x1,y2-r/2,    W3-2*r,y2+r, W3,y2+r, W3+2*r,y2+r,   3*W4,y2-r/2, 3*W4,y2-r/2, 3*W4,y2-r/2,   x2,y2+r, x2,y2+r, x2,y2+r,), 0)
	if style_bottom==15:
		pdb.gimp_vectors_stroke_new_from_points(new_vectors_e, 0, 18, (x1,y2-r/4, x1,y2-r/4, x1,y2-r/4,   W2,y2+3*r/2, W2,y2+3*r/2, W2,y2+3*r/2,   x2,y2-r/4, x2,y2-r/4, x2,y2-r/4), 0)	
	
	b=add_back+r/2
	pdb.gimp_layer_resize(layer, x2-x1+2*b, y2-y1+2*int+2*b,0+b,int+b,)
	pdb.gimp_image_resize_to_layers(image)	
	
	try:
		gimp.Display(image)
	except:
		pass

	pdb.gimp_image_set_active_vectors(image, x)	

	pdb.python_fu_ofn_bend_path(image ,x ,new_vectors_e , 0, 0, 0, 0, run_mode=RUN_NONINTERACTIVE)
	active_vectors = pdb.gimp_image_get_active_vectors(image)
	x.visible = False
	pdb.gimp_image_remove_layer(image, text_layer)
	pdb.gimp_selection_none(image)
	layer.fill(1)
	
	pdb.gimp_selection_none(image)
	new_vectors = []


	if fill==1:   # "With Pattern", 
		W = pdb.gimp_image_width(image)  #szer
		H = pdb.gimp_image_height(image)
	
	#Select the vectors, this is like front end's "Path To Selection"
		pdb.gimp_image_select_item(image,CHANNEL_OP_REPLACE,active_vectors)
		fill_layer = gimp.Layer(image, "Fill Pattern", W, H, RGBA_IMAGE, 100, 0)
		image.add_layer(fill_layer, -1)
		
	#Set context pattern and fill selection with pattern fill
		pdb.gimp_context_set_pattern(fillpattern)
		if gimp.version >= (2,9,0):       
			pdb.gimp_edit_fill(fill_layer,FILL_PATTERN)	      	    #GIMP 2.9
		else:
			pdb.gimp_edit_fill(fill_layer,PATTERN_FILL)             #GIMP 2.8

	# Now we select None so that Stroke path call later will stroke the whole path and not just selected area
		pdb.gimp_selection_none(image)

	if fill==2:	#  "With Foreground", 
		W = pdb.gimp_image_width(image)  #szer
		H = pdb.gimp_image_height(image)

		pdb.gimp_image_select_item(image,CHANNEL_OP_REPLACE,active_vectors)
		fill_layer = gimp.Layer(image, "Fill Foreground", W, H, RGBA_IMAGE, 100, 0)
		image.add_layer(fill_layer, -1)

		if gimp.version >= (2,9,0):       
			pdb.gimp_edit_fill(fill_layer,FILL_FOREGROUND)	       #GIMP 2.9
		else:
			pdb.gimp_edit_fill(fill_layer,FOREGROUND_FILL)         #GIMP 2.8

		pdb.gimp_selection_none(image)

	if fill==3:   # "With Background"
		W = pdb.gimp_image_width(image)
		H = pdb.gimp_image_height(image)

		pdb.gimp_image_select_item(image,CHANNEL_OP_REPLACE,active_vectors)
		fill_layer = gimp.Layer(image, "Fill Background", W, H, RGBA_IMAGE, 100, 0)
		image.add_layer(fill_layer, -1)

		if gimp.version >= (2,9,0):       
			pdb.gimp_edit_fill(fill_layer,FILL_BACKGROUND)	       #GIMP 2.9
		else:
			pdb.gimp_edit_fill(fill_layer,BACKGROUND_FILL)         #GIMP 2.8

		pdb.gimp_selection_none(image)
		
	#if metallic==1:      
		#pdb.python_fu_Custom_Font_Metallic_Effects_v0_03(image, layer, 2, 2, 0, 60, 0, "wood 1", 30, 1.5, 7, 30.0, 0, 0, 50, 0, .5, 150, 1, 0, run_mode=RUN_INTERACTIVE)	
	
	if stroke==1:
		pdb.gimp_selection_none(image)
		W = pdb.gimp_image_width(image)
		H = pdb.gimp_image_height(image)
		stroke_b = gimp.Layer(image, "Stroke brush", W, H, RGBA_IMAGE, 100, 0)
		image.add_layer(stroke_b, -1)
		pdb.gimp_edit_stroke_vectors(stroke_b ,active_vectors)
		
	if stroke==2 or stroke==3:
		if fill==0:
			W = pdb.gimp_image_width(image)  #szer
			H = pdb.gimp_image_height(image)

			pdb.gimp_image_select_item(image,CHANNEL_OP_REPLACE,active_vectors)
			fill_layer = gimp.Layer(image, "Fill", W, H, RGBA_IMAGE, 100, 0)
			image.add_layer(fill_layer, -1)

			#pdb.gimp_context_set_pattern(fillpattern)
			# FILL-FOREGROUND (0), FILL-BACKGROUND (1), FILL-WHITE (2), FILL-TRANSPARENT (3), FILL-PATTERN (4)
		 
		if stroke==2:
			pdb.python_layer_fx_inner_glow(image ,fill_layer, (256,256,256) ,100 ,1 ,1 ,1 ,1 ,1 ,10 ,FALSE,run_mode=RUN_INTERACTIVE)

#pdb.python_layerfx_inner_glow(run-mode ,image ,drawable ,color ,opacity ,contour ,noise ,mode ,source ,choke ,size ,merge)
#COLOR color The glow's color. You can also use a gradient name here. 
#FLOAT opacity The glow's opacity (0 <= opacity <= 100)
#INT32 contour A contour used to modify the glow's intensity curve (0 <= contour <= 11)
#FLOAT noise The amount of noise applied to the glow (0 <= noise <= 100)
#INT32 mode The glow layer's combination mode { NORMAL-MODE (0), DISSOLVE-MODE (1), MULTIPLY-MODE (3), SCREEN-MODE (4), OVERLAY-MODE (5), DIFFERENCE-MODE (6), ADDITION-MODE (7), SUBTRACT-MODE (8), DARKEN-ONLY-MODE (9), LIGHTEN-ONLY-MODE (10),HUE-MODE (11), SATURATION-MODE (12),
#                                               COLOR-MODE (13), VALUE-MODE (14), DIVIDE-MODE (15), DODGE-MODE (16), BURN-MODE (17), HARDLIGHT-MODE (18), SOFTLIGHT-MODE (19), GRAIN-EXTRACT-MODE (20), GRAIN-MERGE-MODE (21), COLOR-ERASE-MODE (22), ERASE-MODE (23), REPLACE-MODE (24), ANTI-ERASE-MODE (25) }
#INT32 source Source (0 = Center, 1 = Edge)
#FLOAT choke Choke (0 <= choke <= 100)
#INT32 size The size of the glow's blur (0 <= size <= 250)
#INT32 merge Merge with layer (TRUE or FALSE)		


		if stroke==3:
			pdb.python_layer_fx_outer_glow(image ,fill_layer, (256,256,256) ,100 ,1 ,1 ,1, 1, 1 ,FALSE ,FALSE, run_mode=RUN_INTERACTIVE)
	pdb.gimp_item_set_visible(layer, 0)	
#pdb.python_layer_fx_outer_glow(run-mode ,image ,drawable ,color ,opacity ,contour ,noise ,mode ,spread ,size ,knockout ,merge)
#FLOAT spread Spread (0 <= spread <= 100)
#INT32 size The size of the glow's blur (0 <= size <= 250)
#INT32 knockout Layer knocks out Outer Glow (TRUE or FALSE)
#INT32 merge Merge with layer (TRUE or FALSE)
	pdb.gimp_selection_none(image)
	
	if flatten:
	    image.merge_visible_layers(CLIP_TO_IMAGE)
	if visible_v==0:
		pdb.gimp_item_set_visible(active_vectors, False)
		pdb.gimp_item_set_visible(new_vectors_e, False)	
	
#=====================================================================================================================			

register(
	"python_fu_text_to_ofn-bend-path",
	"Creating bend-text-logo v.0.5. Necessary for action: \n- Ofn-bend-path.py by Ofnuts (non-interactive)\n- LayerFX.py for Stroke: FX Inner/Outer Glow (interactive)",
	"Creates logo with specified text and ofn-bend-path.py",
	"GPL",
	"MareroQ",
	"2019",
	"Bend Text-Logo...",
	"",
	[
        (PF_TEXT, 	"text", ("Text:"), "GIMPCHAT"),
        (PF_SPINNER, "int", "Intensity (max. bending distance):", 50, (0, 1000, 1)),
        (PF_FONT, "font", "Font:", "Arial"),
        (PF_OPTION, "just", "Justify:", 2, ["LEFT","RIGHT","CENTER"]),
        (PF_SPINNER, "letter_spacing", "Letter Spacing:", 0, (-100, 100, 1, 5, 0, 0)),
        (PF_SPINNER, "line_spacing", "Line Spacing:", 0, ( -100, 100, 1, 5, 0, 0)),
        (PF_INT, "font_size", "Font size:", 150),
        (PF_COLOR, "background_color", "Background color:", (255, 255, 255)),
        (PF_SLIDER, "background_opacity", "Background opacity:", 100, (0, 100, 1)),
        (PF_OPTION,   "style_top", "Top envelope style:", 0, [
        u'\u25E0'"    Bulging up",
        u'\u25E1'"    Bulging down",
        u'\uFE58'"    A straight line",		
        u'\u2227'"    Bent up (roof)",
        u'\u2228'"    Bent down (wedge)",		
        u'\uFF0F'"    Slash",		
        u'\uFF3C'"    BackSlash",
        u'\u223C'"    Wave (tilde)",		
        u'\u223D'"    Wave (reversed tilde)",
        u'\uFE39'"    Tortoise shell",
        u'\uFE3A'"    Tortoise shell reversed",	
        u'\u25DE'"    Arc Trumpet right (upper)",
        u'\u25DF'"    Arc Trumpet left (upper)",
        u'\u21A3'"    Fish right (upper)",
        u'\u21A2'"    Fish left (upper)",
        u'\u25E0\u25E0'"   Heart (upper)",		
        ]),
        (PF_OPTION,   "style_top", "Bottom envelope style:", 1, [
        u'\u25E0'"    Bulging up",
        u'\u25E1'"    Bulging down",
        u'\uFE58'"    A straight line",
        u'\u2227'"    Bent up (roof)",
        u'\u2228'"    Bent down (wedge)",
        u'\uFF0F'"    Slash",		
        u'\uFF3C'"    BackSlash",
        u'\u223C'"    Wave (tilde)",		
        u'\u223D'"    Wave (reversed tilde)",
        u'\uFE39'"    Tortoise shell",
        u'\uFE3A'"    Tortoise shell reversed",
        u'\u25DD'"    Arc Trumpet right (lower)",
        u'\u25DC'"    Arc Trumpet left (lower)",
        u'\u21A3'"    Fish right (lower)",
        u'\u21A2'"    Fish left (lower)",
        " V     Heart (lower)",		
        ]),
        (PF_SPINNER, "add_back", "Enlarge BG (add margin-px):", 10, (0, 1000, 1, 5, 0, 0)),		
        (PF_OPTION, "fill", "FILL (path to selection)?:", 1, ["Don't fill", "With Pattern", "With Foreground", "With Background"]),		
        (PF_PATTERN, "fillpattern", "Fill Pattern:", 0),
        #(PF_BOOL,  "metallic", "Use Metallic Effects?\n (only Gimp-2.10)", False),		
        (PF_OPTION, "stroke", "Stroke:", 1, ["Don't stroke", "With active brush and FG color", "FX Inner Glow", "FX Outer Glow"]),
        (PF_BOOL,  "flatten", "Flatten layers?", False),
        (PF_BOOL,  "visible_v", "Path visible ?", False),			
	],
	[],
	python_fu_text_to_ofn_bend_path,
	menu="<Image>/File/Create/Logos",
	)

main()

